/* Author:ABV

*/
"use strict";



// Dice Roller =====================================================================
function Roll(dice,die) {
    // dice = number of dice to roll
    // die = sides on die
    // ex:  roll(3, 6);  === 3d6

    var result = 0;
    for (var i = 0; i < dice; i++) {
        result += Math.round(Math.random() * die) % die + 1;
    }
    return result;
}



// keyboard constant definitions

var KEYCODE_ENTER = 13;		
var KEYCODE_SPACE = 32;
var KEYCODE_SHIFT = 16;	
var KEYCODE_LEFT = 37;		
var KEYCODE_UP = 38;		
var KEYCODE_RIGHT = 39;
var KEYCODE_DOWN = 40;		
var KEYCODE_Z = 90;			
var KEYCODE_X = 88;			
var KEYCODE_C = 67;			

// input booleans
var leftHeld;			//is the user holding left command
var upHeld;				//is the user holding up command
var rightHeld;			//is the user holding right command
var downHeld;			//is the user holding down command

var spaceHeld;			//is the user holding space command
var zHeld;				//is the user holding z command
var xHeld;				//is the user holding x command
var cHeld;				//is the user holding c command


// Game Constants
var STARTING_ENEMIES = 10;
var MAX_ENEMIES = 30;

var STARTING_FOOD = 100; // 100
var FULLNESS_DURATION = 60;
var SICKNESS_FACTOR = 20;
var SICKNESS_CHANCE = .75;
var FRAMES_PER_DAY = 120;

var DEBUG = false;





// game object setup
var canvas;
var stage;
var container;
var preload;
var debugtext;
var hud;
var enemies = [];
var wolfdude;
var messageField;

var assets = [];
var ground;
var startscreen;
var restartscreen;

// sprite graphics containers
var gfxWolf, gfxRabbit, gfxBabyRabbit, gfxJack, gfxBabyJack, gfxDemon, gfxBabyDemon, gfxGround, gfxStart, gfxRestart;

var loadingInterval = 0;

var framecount = 0;
var days = 0;


var musicOn = true;
var sfxVol = 1;
var paused = false;


//register key/click functions
$(document).bind({
	keydown: handleKeyDown,
	keyup: handleKeyUp
});


$('#musictoggle').bind({
    click: toggleMusic
});
$('#sfxtoggle').bind({
    click: toggleSfx
});


function init() {


    // begin loading content
    var manifest = [
        {id:"grass-texture", src:"img/grass-texture.png"},
        {id:"wolf-sprite", src:"img/wolf-sprite.png"},
        
        {id:"start-screen", src:"img/start-screen.png"},
        {id:"restart-screen", src:"img/dead-screen.png"},
        
        {id:"baby-rabbit-sprite", src:"img/baby-rabbit-sprite.png"},
        {id:"baby-jack-sprite", src:"img/baby-jack-sprite.png"},
        {id:"baby-demon-sprite", src:"img/baby-demon-sprite.png"},
        
        {id:"rabbit-sprite", src:"img/rabbit-sprite.png"},
        {id:"jack-sprite", src:"img/jack-sprite.png"},
        {id:"demon-sprite", src:"img/demon-sprite.png"},
    
        {id:"death", src:"audio/Death.mp3|audio/Death.ogg"},
        {id:"fat", src:"audio/Fat.mp3|audio/Fat.ogg"},
        {id:"chomp", src:"audio/Chomp.mp3|audio/Chomp.ogg"},
        {id:"adult-chirp", src:"audio/AdultChirp.mp3|audio/AdultChirp.ogg"},
        {id:"adult-chirp2", src:"audio/AdultChirp2.mp3|audio/AdultChirp2.ogg"},
        {id:"baby-chirp", src:"audio/BabyChirp.mp3|audio/BabyChirp.ogg"},
        {id:"baby-chirp2", src:"audio/BabyChirp2.mp3|audio/BabyChirp2.ogg"},
        {id:"evil-chirp", src:"audio/EvilChirp.mp3|audio/EvilChirp.ogg"},
        {id:"evil-chirp2", src:"audio/EvilChirp2.mp3|audio/EvilChirp2.ogg"},
        
        {id:"music", src:"audio/SimpleBasslineLooped.mp3|audio/SimpleBasslineLooped.ogg"}
    ];

    preload = new createjs.PreloadJS();
    preload.onFileLoad = handleFileLoad;
    preload.onComplete = doneLoading;
    preload.installPlugin(createjs.SoundJS);
    preload.loadManifest(manifest);

    // create a new stage and point it at our canvas:
    canvas = document.getElementById("mainCanvas");
    stage = new createjs.Stage(canvas);

    var w = canvas.width;
    var h = canvas.height;
    
    messageField = new createjs.Text("Loading", "bold 24px Arial", "#000");
    messageField.maxWidth = 300;
    messageField.textAlign = "center";
    messageField.x = canvas.width / 2;
    messageField.y = canvas.height / 2;
    stage.addChild(messageField);
   
    
    
    stage.update(); 	//update the stage to show text

    loadingInterval = setInterval(updateLoading, 200);
}


function stop() {
    if (preload != null) { preload.close(); }
    createjs.SoundJS.stop();
}

function updateLoading() {
    messageField.text = "Loading " + (preload.progress*100|0) + "%"
    stage.update();
}
function handleFileLoad(event) {
    assets.push(event);
}

function doneLoading() {
    clearInterval(loadingInterval);

    handleLoadedAssets()
    
    messageField.text = "";
     
    startscreen = new createjs.Shape(new createjs.Graphics().beginBitmapFill(gfxStart).drawRect(0,0,400,300));
    stage.addChild(startscreen);
    stage.update();

    // start the music
    createjs.SoundJS.play("music", createjs.SoundJS.INTERRUPT_NONE, 0, 0, -1, 0.5);

    watchRestart();
}
function handleLoadedAssets() {
    for(var i=0;i<assets.length;i++) {
        var item = assets[i]; //loader.getResult(id);
        var id = item.id;
        var result = item.result;


        switch (id) {
            case "grass-texture":
                gfxGround = result;
                break;
            case "start-screen":
                gfxStart = result;
                break;
                
            case "restart-screen":
                gfxRestart = result;
                break;
        }
    }

}




function watchRestart() {
    //watch for clicks
    stage.addChild(messageField);
    stage.update(); 	//update the stage to show text
    canvas.onclick = handleClick;
}

function handleClick() {
    //prevent extra clicks and hide text
    canvas.onclick = null;
    stage.removeChild(messageField);

    // indicate the player is now on screen
    //createjs.SoundJS.play("begin");

    restart();
}








function restart() {
    
    paused = false;
    days = 0;

    stage.removeAllChildren();
    enemies = new Array();
    
    container = new createjs.Container();
    stage.addChild(container);
    
    var w = canvas.width;
    var h = canvas.height;
       
    ground = new createjs.Shape(new createjs.Graphics().beginBitmapFill(gfxGround).drawRect(0,0,w,h));
    container.addChild(ground);
    
    for (var i = 0; i < STARTING_ENEMIES; i++) {
		enemies[i] = new Rabbit();
        enemies[i].init();
        
        enemies[i].x = Math.floor(Math.random()*w);
        enemies[i].y = Math.floor(Math.random()*h);


		container.addChild(enemies[i].sprite);	
        enemies[i].index = container.children.length -1;
	}

          

    wolfdude = new Wolf();
    wolfdude.init();
    container.addChild(wolfdude.sprite);
    wolfdude.index = container.children.length -1;



    debugtext = new createjs.Text("", "12px Courier", "#f00");
    debugtext.textAlign = "left";
    debugtext.x = 2;
    debugtext.y = 2;
    stage.addChild(debugtext);
      
    hud = new createjs.Text("Food:", "12px Courier", "#000");
    hud.textAlign = "left";
    hud.x = 200;
    hud.y = 2;
    stage.addChild(hud);
    
    // start the tick and point it at the window so we can do some work before updating the stage:
	createjs.Ticker.addListener(window);
    createjs.Ticker.useRAF = true;
    createjs.Ticker.setFPS(60);
    
}





function tick() {


    
    framecount ++;

    /*canvas.width = window.innerWidth;
    canvas.height = window.innerHeight;*/


    var w = canvas.width;
    var h = canvas.height;

    var cx = canvas.width/2;
    var cy = canvas.height/2;
    
    // UPDATE FPS COUNTER
    if (createjs.Ticker.getMeasuredFPS() > 30) {
        debugtext.color = "#00d";
    } else {
        debugtext.color + "#f00";
    }
    debugtext.text = "FPS: " + Math.round(createjs.Ticker.getMeasuredFPS());
    
    
    
    
    if (!paused) {
       

        // UPDATE wolfdude
        
        var wolfspeed = wolfdude.speed;
        var wasSneaking = wolfdude.sneaking;
        
        if(spaceHeld && !wolfdude.speedboostCD && !wolfdude.fat) { 
            debugtext.text += " SHIFT";
            wolfdude.sneaking = true;
            wolfdude.sprite.alpha = .6;
            wolfdude.threat = 32;
            wolfspeed = wolfdude.speed/3;
        } else {
            if (wasSneaking && (
                leftHeld || rightHeld || upHeld || downHeld)) {
                wolfdude.speedboostCD = 20;
                wolfdude.food -= 2;
            } 
            
            wolfdude.sneaking = false;
            wolfdude.sprite.alpha = 1;
            wolfdude.threat = 64;
            
            if (wolfdude.speedboostCD > 0) {
                wolfspeed = wolfdude.speed*2
                wolfdude.speedboostCD--;

            }
                
        }
        
        if (wolfdude.fat > 0) {
            wolfspeed = 1;
            wolfdude.fat--;
        }
        
        var wolfNewX = wolfdude.x;
        var wolfNewY = wolfdude.y;

        if (leftHeld) {
            debugtext.text += " LEFT";
            wolfNewX -= wolfspeed;
        } else if (rightHeld) {
            debugtext.text += " RIGHT";
            wolfNewX += wolfspeed;
        } 
        
        if (upHeld) {
            debugtext.text += " UP";
            wolfNewY -= wolfspeed;
        } else if (downHeld) { 
            debugtext.text += " DOWN";
            wolfNewY += wolfspeed;
        } 
        
        if (framecount%30 <1) {
            wolfdude.food -=1;

        }
        
        if (framecount%FRAMES_PER_DAY <1) {
            days++;
        }
                
        if (wolfNewX < wolfdude.x) {
            wolfdude.facing = -1;
        } else if  (wolfNewX > wolfdude.x){
            wolfdude.facing = 1;
        } 
      
        wolfdude.x = wolfNewX;
        wolfdude.y = wolfNewY;
      
        stopAtBounds(wolfdude, wolfdude.w/2);

        wolfdude.sprite.scaleX = wolfdude.facing;
        

          
        wolfdude.update();
        if (wolfdude.facing < 0) {
            wolfdude.sprite.x = wolfdude.x + 16;
        } 


        
        // UPDATE ENEMIES
        for (var i = 0; i < enemies.length; i++) {
            
            var enemy = enemies[i]
            
            var d = distance(enemy.x, wolfdude.x, enemy.y, wolfdude.y);
            var dCenterX = Math.abs(enemy.x - cx);
            var dCenterY = Math.abs(enemy.y - cy);

            var threatRadius = wolfdude.threat;
            var movespeed = enemy.speed;
            
            enemy.scared = false;
            
            if (d < threatRadius) { 
                movespeed = enemy.speed*2;
                enemy.scared = true
            } else if (d < (threatRadius/2)) { 
                movespeed = enemy.speed*4;
                enemy.scared = true
            }
            
            var newX = enemy.x;
            var newY = enemy.y;
            
            // simple idle  movement
            if  (d < threatRadius) {
                if (wolfdude.x < enemy.x ) {
                    // move away to the right
                    newX += Math.round(Math.random()*movespeed );

                } else  { 
                    // move away to the left
                    newX -= Math.round(Math.random()*movespeed );

                }
            } else if ((framecount%3 < 1) && Math.random() < .5) {
                if ( dCenterX > 150 ) {
                    // try to move more toward the center
                    if (cx < enemy.x ) {
                        newX -= Math.round(Math.random()*movespeed);
                    } else {
                        newX += Math.round(Math.random()*movespeed);
                    }
                } else {
                    //move randomly 
                    newX += Math.round(Math.random()*movespeed*2) -movespeed;
                }
            } 

                
            
            if (d < threatRadius) {
                if (wolfdude.y < enemy.y) {
                    // move away down
                    newY += Math.round(Math.random()*movespeed );
                } else {
                    // move away up
                    newY -= Math.round(Math.random()*movespeed )
                }
            }  else if ( (framecount%3 < 1) && Math.random() < .5) {
                if ( dCenterY > 100 ) {
                    // try to move more toward the center
                    if (cy < enemy.y ) {
                        newY -= Math.round(Math.random()*movespeed);
                    } else {
                        newY += Math.round(Math.random()*movespeed);
                    }
                } else {
                    //move randomly 
                    newY += Math.round(Math.random()*movespeed*2) -movespeed;
                }
            } 
            /*
            if (newX < enemy.x) {
                enemy.facing = -1;
            } else if (newX > enemy.x) {
                enemy.facing = 1
            }
            */
            enemy.x = newX;
            enemy.y = newY;
            
            if ( isOutOfBounds(enemy, 4) ) {
                placeInBounds(enemy, 4);
            }
            
            //stopAtBounds(enemy, enemy.w/2);
            

            for (var j = 0; j < enemies.length; j++) {
                if (j !== i) {
                    if (objectCollision(enemy, enemies[j])) {
                        
                        if ((enemy.fertility > 300) && 
                            (enemies[j].fertility > 300) && 
                            (enemies.length < MAX_ENEMIES) && 
                            (enemy.adult) && (enemies[j].adult) &&
                            (!enemy.scared) && (!enemies[j].scared) &&
                            (Math.random() > (enemies.length)/(MAX_ENEMIES))) {
                    
                            console.log('enemies[' + i + '] and enemies[' + j + '] make babies' );
                            //makeBabies(enemies[i], enemies[j]);
                            
                            var baby = new Rabbit();
                            baby.init(enemy, enemies[j]);
                            baby.x = enemy.x + Math.floor(Math.random()*16);
                            baby.y = enemy.y + Math.floor(Math.random()*16);
                            
                            container.addChild(baby.sprite);                  
                            
                            enemies.push(baby);
                            
                            enemy.fertility = 0;
                            enemies[j].fertility = 0;
                            
                            if ((framecount%2) <1 ) {
                                createjs.SoundJS.play("baby-chirp", createjs.SoundJS.INTERUPT_LATE, 0, 0, 0, .16*sfxVol, 0);
                            } else {
                                createjs.SoundJS.play("baby-chirp2", createjs.SoundJS.INTERUPT_LATE, 0, 0, 0, .16*sfxVol, 0);
                            }
                        }
                    }
                }
            }

            enemy.fertility += Roll(1,2);
            enemy.age += 1/30;
            
            if ((enemy.age > 20) && (enemy.adult == false)) {
                // baby grows up
                console.log('enemies[' + i + '] grows up');
                enemy.size = enemy.fullsize;
                enemy.adult = true;
                enemy.sprite.scaleX = enemy.fullsize/enemy.w * enemy.facing;
                enemy.sprite.scaleY = enemy.fullsize/enemy.w;
                
                if (enemy.fullsize < 8 ) {
                    enemy.speed = 4;
                }
                enemy.fertility = 0;
                
                switch (enemy.health) {
                    case 'weak':
                        //enemy.sprite = new createjs.Bitmap('img/jack-sprite.png');
                        if ((framecount%2) <1 ) {
                            createjs.SoundJS.play("adult-chirp", createjs.SoundJS.INTERUPT_LATE, 0, 0, 0, .6*sfxVol, 0);
                        } else { 
                            createjs.SoundJS.play("adult-chirp2", createjs.SoundJS.INTERUPT_LATE, 0, 0, 0, .6*sfxVol, 0);
                        }
                        break;
                    case 'sick':
                        //enemy.sprite = new createjs.Bitmap('img/demon-sprite.png');
                        if ((framecount%2) <1 ) {
                            createjs.SoundJS.play("evil-chirp", createjs.SoundJS.INTERUPT_LATE, 0, 0, 0, .8*sfxVol, 0);
                        } else { 
                            createjs.SoundJS.play("evil-chirp2", createjs.SoundJS.INTERUPT_LATE, 0, 0, 0, .6*sfxVol, 0);
                        }
                        break;
                    default:
                        //enemy.sprite = new createjs.Bitmap('img/rabbit-sprite.png');
                        if ((framecount%2) <1 ) {
                            createjs.SoundJS.play("adult-chirp", createjs.SoundJS.INTERUPT_LATE, 0, 0, 0, .6*sfxVol, 0);
                        } else { 
                            createjs.SoundJS.play("adult-chirp2", createjs.SoundJS.INTERUPT_LATE, 0, 0, 0, .6*sfxVol, 0);
                        }
                        break;
                }
                
  
                
                
             
                
            }
            
           
            enemies[i].update();
            
            if (objectCollision(enemy, wolfdude)) {
                console.log('enemies[' + i + ']');
                enemy.die();
                
                createjs.SoundJS.play("chomp", createjs.SoundJS.INTERUPT_LATE, 0, 0, 0, .5*sfxVol, 0);
                
                if (enemy.health == 'sick') {
                    wolfdude.food -= 0;
                    wolfdude.fat = FULLNESS_DURATION;
                    createjs.SoundJS.play("fat", createjs.SoundJS.INTERUPT_LATE, 0, 0, 0, .2*sfxVol, 0);
                } else if (enemy.health == 'weak') {
                    wolfdude.food += Math.round(enemy.size/2);
                } else {
                    wolfdude.food += Math.round(enemy.size);
                }

                
                if (wolfdude.food > STARTING_FOOD) {
                    wolfdude.food = STARTING_FOOD;
                    wolfdude.fat = FULLNESS_DURATION;
                    createjs.SoundJS.play("fat", createjs.SoundJS.INTERUPT_LATE, 0, 0, 0, .2*sfxVol, 0);
                }
                container.removeChild(enemy.sprite);
                enemies.splice(i,1);
            }
            
            if (enemy.age > 94) {
                enemy.sprite.alpha = .5;
                enemy.speed = 1;
            }

            
            if (enemy.age > 100) {
                console.log('OLD AGE enemies[' + i + ']');
                enemy.die();
                container.removeChild(enemy.sprite);
                enemies.splice(i,1);
            }

        }

        hud.text = "FOOD: " + wolfdude.food + "  DAYS: " + days;
            
            
        if (wolfdude.food <= 0)  {
            endGame();
        }
            

       
    }
    
    
    
   
   
    
   
        
        
        
        
        
    
    //hide text for debug
    if (!DEBUG) {
        debugtext.y = -100;
    } else {
        debugtext.y = 2;
    }
	
	
    // draw the updates to stage:
    stage.update();
}

function toggleMusic(e) {
    if (musicOn) {
        musicOn = false;
        $('#musictoggle').text('MUSIC: OFF');
        createjs.SoundJS.setVolume( 0, 'music');
    } else {
        musicOn = true;
        $('#musictoggle').text('MUSIC: ON');
        createjs.SoundJS.setVolume( .5, 'music');
    }
}

function toggleSfx(e) {
    if (sfxVol > 0) {
        sfxVol = 0;
        $('#sfxtoggle').text('SOUND: OFF');
    } else {
        sfxVol = 1;
        $('#sfxtoggle').text('SOUND: ON');
    }
}


function endGame() {
    paused = true;
    stage.removeChild(wolfdude.sprite);
    messageField.text = "";
    stage.addChild(messageField);



    //play death sound
    createjs.SoundJS.play("death", createjs.SoundJS.INTERUPT_LATE, 0, 0, 0, .5*sfxVol, 0);
    
    
    restartscreen = new createjs.Bitmap(gfxRestart);
    stage.addChild(restartscreen);
    stage.update();

    
    watchRestart();

}






//allow for arrow control scheme
function handleKeyDown(e) {
	//cross browser issues exist
	if(!e){ var e = window.event; }
	switch(e.keyCode) {
		case KEYCODE_LEFT:	leftHeld = true; break;
		case KEYCODE_UP:	upHeld = true; break;
		case KEYCODE_RIGHT: rightHeld = true; break;
		case KEYCODE_DOWN: downHeld = true; break;
        case KEYCODE_SPACE:	spaceHeld = true; break;
        case KEYCODE_ENTER: if(canvas.onclick == handleClick){ handleClick(); }return false;
		break;
	}
}

function handleKeyUp(e) {
	//cross browser issues exist
	if(!e){ var e = window.event; }
	switch(e.keyCode) {
		case KEYCODE_LEFT:	leftHeld = false; break;
		case KEYCODE_UP:	upHeld = false; break;
		case KEYCODE_RIGHT: rightHeld = false; break;
		case KEYCODE_DOWN: downHeld = false; break;
        case KEYCODE_SPACE:	spaceHeld = false; break;
		break;
	}
}


function isOutOfBounds(object, buffer) {
    return (object.x < -(buffer)) || (object.x > (canvas.width + buffer)) ||
        (object.y < -(buffer)) || (object.y > (canvas.height + buffer));

}

function placeInBounds(object, buffer) {
    if (object.x < -(buffer)) {
        // oob to the left
        object.x += (canvas.width + buffer);
    } else if (object.x > (canvas.width + buffer)) {
        // oob to the right
        object.x -= (canvas.width + buffer*2);
    }
    
    if (object.y < -(buffer)) {
        // oob to top
        object.y += (canvas.height + buffer);
    } else if (object.y > (canvas.height + buffer)) {
        object.y -= (canvas.height + buffer*2);
    }
}

function stopAtBounds(nextPos, buffer) {
    if (nextPos.x <= (0+buffer)) {
        // oob to the left
        nextPos.x = 0+buffer;
    } else if (nextPos.x >= (canvas.width-buffer)) {
        // oob to the right
        nextPos.x = canvas.width-buffer;
    }
    
    if (nextPos.y <= (0+buffer)) {
        // oob to top
        nextPos.y = buffer;
    } else if (nextPos.y >= (canvas.height - buffer)) {
        // oob to bottom
        nextPos.y = canvas.height-buffer;
    }
    

}

function objectCollision(o1, o2) {

    var r1 = {},
    r2 = {};

    r1.x = o1.x - (o1.w/2);
    r1.y = o1.y - (o1.h/2);
    r1.w = o1.w;
    r1.h = o1.h;
    
    
    r2.x = o2.x - (o2.w/2);
    r2.y = o2.y - (o2.h/2);
    r2.w = o2.w;
    r2.h = o2.h;
    
    return intersectRect(r1, r2);
        
}

function intersectRect(r1, r2) {
    // based on http://stackoverflow.com/questions/2752349/fast-rectangle-to-rectangle-intersection
    if (!r1 || !r2) return false;
    
    return !(r2.x > r1.x+r1.w ||  // r2 is right of r1
           r2.x+r2.w < r1.x ||  // r2 is left of r1
           r2.y > r1.y+r1.w ||  // r2 is below r1
           r2.y+r2.h < r1.y);   // r2 is abovel r1
}


function distance(x1, x2, y1, y2) {
    return Math.sqrt( Math.pow((x2 - x1),2) + Math.pow((y2 - y1),2));
}

// CLASSES ===================


// Base game object -----------------
var GameObject = function() {
    this.sprite = null; // graphics or bitmap animation
    this.x = 0; // origin x
    this.y = 0; // origin y
    this.w = 0; // width used for collisions
    this.h = 0; // height, used for collisions
    this.index = 0;
    
    this.state = null;
}


GameObject.prototype.init = function () {
    // base game object initialization
}

GameObject.prototype.update = function() {
    // pass the objects world x/y to the sprite
    if (this.sprite) {
        this.sprite.x = this.x - this.w/2;
        this.sprite.y = this.y - this.h/2;
    }
}

// Wolf -----------------
var Wolf = function() {
    // inherit constructors from game object
    GameObject.call(this);
    

}

// inherit properties and functions
Wolf.prototype = new GameObject();

Wolf.prototype.init = function() {
    GameObject.prototype.init();
    this.w = 32;
    this.h = 32;
    this.x = (canvas.width-this.w) / 2;
    this.y = (canvas.height-this.h) / 2;
    
    this.facing = -1;
    
    
    
   /*
    this.sprite = new createjs.Shape();
    this.sprite.graphics.beginFill('#f00');
    this.sprite.graphics.drawRect(0,0,this.w,this.h);
   
    // set up sprite for wolf 
    var spriteSheetData = {
        images: ["wolf-sprite", "../img/wolf-sprite.png"],
        frames: {width:32, height:32, count:1, regX: 32, regY:32},
        animations: {
            // start, end, next, frequency
            idle: [0]
        }
    } 
    
    this.spritesheet = createjs.SpriteSheet(spriteSheetData);
    this.sprite = new createjs.BitmapAnimation(this.spritesheet);
    
    this.spritesheet.getAnimation("idle").next = "idle";
    this.sprite.gotoAndPlay("idle");
    */
    
    this.sprite = new createjs.Bitmap('img/wolf-sprite.png');
    
    
    
    this.sprite.x = this.x;
    this.sprite.y = this.y;
    
    this.speed = 3;
    this.food = STARTING_FOOD;
    this.threat = 64;
    this.sneaking = false;
    
    this.speedboostCD = 0;
    this.fatCD = 0;

}

Wolf.prototype.bark = function() {
    console.log('bark');
}




// Rabbit -----------------
var Rabbit = function() {
    // inherit constructors from game object
    GameObject.call(this);
}

// inherit properties and functions
Rabbit.prototype = new GameObject();

// define methods
Rabbit.prototype.init = function(p1,p2) {
    
    this.speed = 2
    this.w = 8;
    this.h = 8;
    this.health = 'healthy';
    this.facing = 1;
    
    
    if (p1 && p2) { 
        console.log('baby!')
      
        if (Math.random() > .5) {
            this.fullsize = p1.fullsize;
        } else {
            this.fullsize = p2.fullsize;
        }
        this.fullsize += Roll(1,6)-4;
        
        if (this.fullsize < 6){
            this.fullsize = 6;
        } else if (this.fullsize >12) {
            this.fullsize = 12;
        }
        
        this.size = 2;
        this.adult = false;
 
        
        this.fertility = -300;


        this.age = 0;
        
        if ((Math.random()) > (SICKNESS_FACTOR/(days+1)) ){
            if (Math.random() < SICKNESS_CHANCE) {
                this.health = 'weak';
            }
        }
        
        if (((p1.health == 'weak') || (p1.health == 'sick')) && 
            ((p2.health == 'weak') || (p2.health == 'sick'))) {
            this.health = 'sick';
        }

        this.x = Math.random()*canvas.width;
        this.y = Math.random()*canvas.width;
        
        //this.sprite = new createjs.Shape();
        switch (this.health) {
            case 'weak':
                //this.sprite.graphics.beginFill('#0f8');
                this.sprite = new createjs.Bitmap('img/jack-sprite.png');
                break
            case 'sick':
                //this.sprite.graphics.beginFill('#ee2');
                this.sprite = new createjs.Bitmap('img/demon-sprite.png');
                break;
            default:
                //this.sprite.graphics.beginFill('#08f');
                this.sprite = new createjs.Bitmap('img/rabbit-sprite.png');
                break;
        }
        //this.sprite.graphics.drawRect(0,0,this.w,this.h);

        this.sprite.scaleX = this.fullsize / 2 / this.fullsize * this.facing;
        this.sprite.scaleY = this.fullsize / 2 / this.fullsize;
        
    } else {
        console.log('adult')
        this.fullsize = 7 + Roll(1,2);
        this.size = this.fullsize;
        this.adult = true;
        
        this.fertility = 0;
        this.age = 20 + Roll(1,20);
        
        this.x = Math.random()*canvas.width;
        this.y = Math.random()*canvas.width;

        
        //this.sprite = new createjs.Shape();
        //this.sprite.graphics.beginFill('#08f');
        //this.sprite.graphics.drawRect(0,0,this.w,this.h);
        
        this.sprite = new createjs.Bitmap('img/rabbit-sprite.png');
        
        this.sprite.scaleX = this.fullsize/this.w * this.facing;
        this.sprite.scaleY = this.fullsize/this.w;
    }
 
 
            
    this.sprite.x = this.x;
    this.sprite.y = this.y;

}

Rabbit.prototype.die = function() {

    console.log('rabbit died');
}














$(document).ready(init());









